@@ -11,5 +11,5 @@ DEFAULT_CONFIG_DATA = {
     "APP": {},
     "profile": {}
 }
-CODEC_HIGH_QUALITY = "LC_128_44100_stereo"
-CODEC_NORMAL_QUALITY = "LC_64_44100_stereo"
+CODEC_HIGH_QUALITY = "AAX_44_128"
+CODEC_NORMAL_QUALITY = "AAX_44_64"
